==> java-cxf-spring-server-generator-0.13.2.tgz: package/test-output/junit5/idkit_v1-openapi_spec.yml/src/main/java/com/example/model/VerificationOutcome.java <==
package com.example.model;

/**
 * Model for VerificationOutcome
 */
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-04-05T19:55:16.329Z")
@io.swagger.annotations.ApiModel(value = "VerificationOutcome", description = "Model for VerificationOutcome")
@javax.xml.bind.annotation.XmlRootElement(name = "VerificationOutcome")
public class VerificationOutcome implements java.io.Serializable {

	private static final long serialVersionUID = 1L;
	private java.lang.String indicator = null;
	private java.lang.String totalPoints = null;
	
	/**
	 */
	public VerificationOutcome indicator(java.lang.String indicator) {
		setIndicator(indicator);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(required = true, value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("indicator")
	@javax.validation.constraints.NotNull
	public java.lang.String getIndicator() {
		return this.indicator;
	}
	public void setIndicator(java.lang.String indicator) {
		this.indicator = indicator;
	}
	
	/**
	 */
	public VerificationOutcome totalPoints(java.lang.String totalPoints) {
		setTotalPoints(totalPoints);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("totalPoints")
	public java.lang.String getTotalPoints() {
		return this.totalPoints;
	}
	public void setTotalPoints(java.lang.String totalPoints) {
		this.totalPoints = totalPoints;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		VerificationOutcome verificationOutcome = (VerificationOutcome) o;
		return java.util.Objects.equals(this.indicator, verificationOutcome.indicator)
				&& java.util.Objects.equals(this.totalPoints, verificationOutcome.totalPoints);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.indicator, this.totalPoints);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class VerificationOutcome {\n");
		
		sb.append("    indicator: ").append(toIndentedString(this.indicator)).append("\n");
		sb.append("    totalPoints: ").append(toIndentedString(this.totalPoints)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}

==> java-cxf-spring-server-generator-0.14.0.tgz: package/test-output/junit5/idkit_v1-openapi_spec.yml/src/main/java/com/example/model/VerificationOutcome.java <==
package com.example.model;

/**
 * Model for VerificationOutcome
 */
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-04-09T22:14:49.443Z")
@io.swagger.v3.oas.annotations.media.Schema(name = "VerificationOutcome", description = "Model for VerificationOutcome")
@javax.xml.bind.annotation.XmlRootElement(name = "VerificationOutcome")
public class VerificationOutcome implements java.io.Serializable {

	private static final long serialVersionUID = 1L;
	private java.lang.String indicator = null;
	private java.lang.String totalPoints = null;
	
	/**
	 */
	public VerificationOutcome indicator(java.lang.String indicator) {
		setIndicator(indicator);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(required = true, name = "indicator")
	@com.fasterxml.jackson.annotation.JsonProperty("indicator")
	@javax.validation.constraints.NotNull
	public java.lang.String getIndicator() {
		return this.indicator;
	}
	public void setIndicator(java.lang.String indicator) {
		this.indicator = indicator;
	}
	
	/**
	 */
	public VerificationOutcome totalPoints(java.lang.String totalPoints) {
		setTotalPoints(totalPoints);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "totalPoints")
	@com.fasterxml.jackson.annotation.JsonProperty("totalPoints")
	public java.lang.String getTotalPoints() {
		return this.totalPoints;
	}
	public void setTotalPoints(java.lang.String totalPoints) {
		this.totalPoints = totalPoints;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		VerificationOutcome verificationOutcome = (VerificationOutcome) o;
		return java.util.Objects.equals(this.indicator, verificationOutcome.indicator)
				&& java.util.Objects.equals(this.totalPoints, verificationOutcome.totalPoints);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.indicator, this.totalPoints);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class VerificationOutcome {\n");
		
		sb.append("    indicator: ").append(toIndentedString(this.indicator)).append("\n");
		sb.append("    totalPoints: ").append(toIndentedString(this.totalPoints)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}
